pub enum Part {
Text {
text: String,
thought: Option<bool>,
thought_signature: Option<String>,
},
InlineData {
inline_data: Blob,
},
FileData {
file_data: FileDataRef,
},
FunctionCall {
function_call: FunctionCall,
thought_signature: Option<String>,
},
FunctionResponse {
function_response: FunctionResponse,
thought_signature: Option<String>,
},
ToolCall {
tool_call: Value,
thought_signature: Option<String>,
},
ToolResponse {
tool_response: Value,
thought_signature: Option<String>,
},
ExecutableCode {
executable_code: Value,
thought_signature: Option<String>,
},
CodeExecutionResult {
code_execution_result: Value,
thought_signature: Option<String>,
},
}Expand description
Core primitive types for building requests and parsing responses Content part that can be included in a message
Variants
Text
Text content
Fields
InlineData
FileData
File data referenced by URI
Fields

file_data: FileDataRefFunctionCall
Function call from the model
Fields

function_call: FunctionCallThe function call details
FunctionResponse
Function response (results from executing a function call)
Fields

function_response: FunctionResponseThe function response details
ToolCall
Server-side tool call from Gemini 3 (built-in tool invocation)
Fields
ToolResponse
Server-side tool response from Gemini 3 (built-in tool result)
Fields
ExecutableCode
Generated code emitted by Gemini code execution.
Fields
CodeExecutionResult
Result emitted by Gemini code execution.