pub struct FileDataRef {
pub mime_type: String,
pub file_uri: String,
}Expand description
Core primitive types for building requests and parsing responses Reference to an external file by URI, used in Gemini wire format.
Example
use adk_gemini::FileDataRef;
let file_ref = FileDataRef {
mime_type: "application/pdf".to_string(),
file_uri: "gs://my-bucket/report.pdf".to_string(),
};Fields
mime_type: Stringfile_uri: StringTrait Implementations
Sourceimpl Clone for FileDataRef
impl Clone for FileDataRef
Sourcefn clone(&self) -> FileDataRef
fn clone(&self) -> FileDataRef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileDataRef
impl Debug for FileDataRef
Sourceimpl<'de> Deserialize<'de> for FileDataRef
impl<'de> Deserialize<'de> for FileDataRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for FileDataRef
impl PartialEq for FileDataRef
Sourcefn eq(&self, other: &FileDataRef) -> bool
fn eq(&self, other: &FileDataRef) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for FileDataRef
impl Serialize for FileDataRef
impl StructuralPartialEq for FileDataRef