pub struct FunctionResponse {
pub name: String,
pub response: Option<Value>,
pub parts: Vec<FunctionResponsePart>,
}Expand description
A response from a function
Fields
name: StringThe name of the function
response: Option<Value>The response from the function This must be a valid JSON object
parts: Vec<FunctionResponsePart>Multimodal parts nested inside the functionResponse wire object.
Contains inlineData and/or fileData entries that accompany the JSON response.
Gemini 3 expects these inside the functionResponse, not as sibling Content parts.
Implementations
Sourceimpl FunctionResponse
impl FunctionResponse
Sourcepub fn new(name: impl Into<String>, response: Value) -> Self
pub fn new(name: impl Into<String>, response: Value) -> Self
Create a new function response with a JSON value
Sourcepub fn with_inline_data(
name: impl Into<String>,
response: Value,
inline_data: Vec<Blob>,
) -> Self
pub fn with_inline_data( name: impl Into<String>, response: Value, inline_data: Vec<Blob>, ) -> Self
Create with JSON response and inline data blobs.
Sourcepub fn with_file_data(
name: impl Into<String>,
response: Value,
file_data: Vec<FileDataRef>,
) -> Self
pub fn with_file_data( name: impl Into<String>, response: Value, file_data: Vec<FileDataRef>, ) -> Self
Create with JSON response and file data references.
Sourcepub fn inline_data_only(name: impl Into<String>, inline_data: Vec<Blob>) -> Self
pub fn inline_data_only(name: impl Into<String>, inline_data: Vec<Blob>) -> Self
Create with inline data only (no JSON response).
Sourcepub fn from_schema<Response>(
name: impl Into<String>,
response: Response,
) -> Result<Self, Error>where
Response: JsonSchema + Serialize,
pub fn from_schema<Response>(
name: impl Into<String>,
response: Response,
) -> Result<Self, Error>where
Response: JsonSchema + Serialize,
Create a new function response from a serializable type that will be parsed as JSON